import { delegateCombine, delegateRemove } from "igniteui-webcomponents-core";
import { IgcValueBrushScaleComponent } from "igniteui-webcomponents-charts";
import { IgcContourValueResolverComponent } from "igniteui-webcomponents-charts";
import { IgcTriangulationStatusEventArgs } from "igniteui-webcomponents-core";
import { IgcGeographicXYTriangulatingSeriesComponent } from "./igc-geographic-xy-triangulating-series-component";
import { GeographicContourLineSeries } from "./GeographicContourLineSeries";
import { getAllPropertyNames, toSpinal } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
/**
 * Represents a class for Geographic Contour Series displayed on a map.
*/
export let IgcGeographicContourLineSeriesComponent = /*@__PURE__*/ (() => {
    class IgcGeographicContourLineSeriesComponent extends IgcGeographicXYTriangulatingSeriesComponent {
        createImplementation() {
            return new GeographicContourLineSeries();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
            this._triangulationStatusChanged = null;
            this._triangulationStatusChanged_wrapped = null;
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcGeographicContourLineSeriesComponent._observedAttributesIgcGeographicContourLineSeriesComponent == null) {
                let names = getAllPropertyNames(IgcGeographicContourLineSeriesComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicContourLineSeriesComponent._observedAttributesIgcGeographicContourLineSeriesComponent = names;
            }
            return IgcGeographicContourLineSeriesComponent._observedAttributesIgcGeographicContourLineSeriesComponent;
        }
        static register() {
            if (!IgcGeographicContourLineSeriesComponent._isElementRegistered) {
                IgcGeographicContourLineSeriesComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcGeographicContourLineSeriesComponent.htmlTagName, IgcGeographicContourLineSeriesComponent);
            }
        }
        /**
         * Gets whether the current series shows a line contour shape.
        */
        get isLineContour() {
            return this.i.ex;
        }
        /**
         * The name of the property from which to retrieve the numeric values from the ItemsSource items.
        */
        get valueMemberPath() {
            return this.i.u4;
        }
        set valueMemberPath(v) {
            this.i.u4 = v;
        }
        /**
         * The ValueBrushScale to use when determining Brushes for each contour line, based on the values found in ValueMemberPath.
        */
        get fillScale() {
            const r = this.i.u0;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                let e = IgcValueBrushScaleComponent._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        }
        set fillScale(v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.u0 = null : this.i.u0 = v.i;
        }
        /**
         * Gets actual fill scale that is set on the FillScale property or default FillScale
        */
        get actualFillScale() {
            const r = this.i.uz;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                let e = IgcValueBrushScaleComponent._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        }
        set actualFillScale(v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.uz = null : this.i.uz = v.i;
        }
        /**
         * The ContourValueResolver used to determine the numeric values of contours.
        */
        get valueResolver() {
            const r = this.i.uw;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                let e = IgcContourValueResolverComponent._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        }
        set valueResolver(v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.uw = null : this.i.uw = v.i;
        }
        findByName(name) {
            var baseResult = super.findByName(name);
            if (baseResult) {
                return baseResult;
            }
            if (this.fillScale && this.fillScale.name && this.fillScale.name == name) {
                return this.fillScale;
            }
            if (this.actualFillScale && this.actualFillScale.name && this.actualFillScale.name == name) {
                return this.actualFillScale;
            }
            if (this.valueResolver && this.valueResolver.name && this.valueResolver.name == name) {
                return this.valueResolver;
            }
            return null;
        }
        _styling(container, component, parent) {
            super._styling(container, component, parent);
            this._inStyling = true;
            if (this.fillScale && this.fillScale._styling) {
                this.fillScale._styling(container, component, this);
            }
            if (this.actualFillScale && this.actualFillScale._styling) {
                this.actualFillScale._styling(container, component, this);
            }
            if (this.valueResolver && this.valueResolver._styling) {
                this.valueResolver._styling(container, component, this);
            }
            this._inStyling = false;
        }
        /**
         * Raised when the status of an ongoing Triangulation has changed.
        */
        get triangulationStatusChanged() {
            return this._triangulationStatusChanged;
        }
        set triangulationStatusChanged(ev) {
            if (this._triangulationStatusChanged_wrapped !== null) {
                this.i.triangulationStatusChanged = delegateRemove(this.i.triangulationStatusChanged, this._triangulationStatusChanged_wrapped);
                this._triangulationStatusChanged_wrapped = null;
                this._triangulationStatusChanged = null;
            }
            this._triangulationStatusChanged = ev;
            this._triangulationStatusChanged_wrapped = (o, e) => {
                let outerArgs = new IgcTriangulationStatusEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeTriangulationStatusChanged) {
                    this.beforeTriangulationStatusChanged(this, outerArgs);
                }
                if (this._triangulationStatusChanged) {
                    this._triangulationStatusChanged(this, outerArgs);
                }
            };
            this.i.triangulationStatusChanged = delegateCombine(this.i.triangulationStatusChanged, this._triangulationStatusChanged_wrapped);
            ;
        }
    }
    IgcGeographicContourLineSeriesComponent._observedAttributesIgcGeographicContourLineSeriesComponent = null;
    IgcGeographicContourLineSeriesComponent.htmlTagName = "igc-geographic-contour-line-series";
    IgcGeographicContourLineSeriesComponent._isElementRegistered = false;
    return IgcGeographicContourLineSeriesComponent;
})();
