import { delegateCombine, delegateRemove } from "igniteui-webcomponents-core";
import { IgcProgressiveLoadStatusEventArgs } from "igniteui-webcomponents-charts";
import { IgcGeographicMapSeriesHostComponent } from "./igc-geographic-map-series-host-component";
import { GeographicHighDensityScatterSeries } from "./GeographicHighDensityScatterSeries";
import { getAllPropertyNames, toSpinal, ensureBool, colorToString, stringToColor } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
/**
 * Series class for a geographic map with points marked at given locations.
 * This is the geographic equivalent of a HighDensityScatterSeries.
*/
export let IgcGeographicHighDensityScatterSeriesComponent = /*@__PURE__*/ (() => {
    class IgcGeographicHighDensityScatterSeriesComponent extends IgcGeographicMapSeriesHostComponent {
        createImplementation() {
            return new GeographicHighDensityScatterSeries();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
            this._progressiveLoadStatusChanged = null;
            this._progressiveLoadStatusChanged_wrapped = null;
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcGeographicHighDensityScatterSeriesComponent._observedAttributesIgcGeographicHighDensityScatterSeriesComponent == null) {
                let names = getAllPropertyNames(IgcGeographicHighDensityScatterSeriesComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicHighDensityScatterSeriesComponent._observedAttributesIgcGeographicHighDensityScatterSeriesComponent = names;
            }
            return IgcGeographicHighDensityScatterSeriesComponent._observedAttributesIgcGeographicHighDensityScatterSeriesComponent;
        }
        static register() {
            if (!IgcGeographicHighDensityScatterSeriesComponent._isElementRegistered) {
                IgcGeographicHighDensityScatterSeriesComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcGeographicHighDensityScatterSeriesComponent.htmlTagName, IgcGeographicHighDensityScatterSeriesComponent);
            }
        }
        /**
         * Gets whether the current series shows pixels.
        */
        get isPixel() {
            return this.i.e2;
        }
        /**
         * The name of the property of ItemsSource items which contains the latitude coordinate of the symbol.
        */
        get latitudeMemberPath() {
            return this.i.us;
        }
        set latitudeMemberPath(v) {
            this.i.us = v;
        }
        /**
         * The name of the property of ItemsSource items which contains the longitude coordinate of the symbol.
        */
        get longitudeMemberPath() {
            return this.i.uu;
        }
        set longitudeMemberPath(v) {
            this.i.uu = v;
        }
        /**
         * Gets or sets the whether to use use brute force mode.
        */
        get useBruteForce() {
            return this.i.uh;
        }
        set useBruteForce(v) {
            this.i.uh = ensureBool(v);
            this._a("useBruteForce", this.i.uh);
        }
        /**
         * Gets or sets the whether to progressively load the data into the chart.
        */
        get progressiveLoad() {
            return this.i.ug;
        }
        set progressiveLoad(v) {
            this.i.ug = ensureBool(v);
            this._a("progressiveLoad", this.i.ug);
        }
        /**
         * Gets or sets the whether the chart reacts to mouse move events.
        */
        get mouseOverEnabled() {
            return this.i.uf;
        }
        set mouseOverEnabled(v) {
            this.i.uf = ensureBool(v);
            this._a("mouseOverEnabled", this.i.uf);
        }
        /**
         * Gets or sets the density value that maps to the minimum heat color.
        */
        get heatMinimum() {
            return this.i.uj;
        }
        set heatMinimum(v) {
            this.i.uj = +v;
            this._a("heatMinimum", this.i.uj);
        }
        /**
         * Gets or sets the value that maps to the maximum heat color.
        */
        get heatMaximum() {
            return this.i.ui;
        }
        set heatMaximum(v) {
            this.i.ui = +v;
            this._a("heatMaximum", this.i.ui);
        }
        /**
         * Gets or sets the color to use for the minimum end of the scale.
        */
        get heatMinimumColor() {
            return colorToString(this.i.vd);
        }
        set heatMinimumColor(v) {
            this.i.vd = stringToColor(v);
            this._a("heatMinimumColor", colorToString(this.i.vd));
        }
        /**
         * Gets or sets the color to use for the maximum end of the scale.
        */
        get heatMaximumColor() {
            return colorToString(this.i.vc);
        }
        set heatMaximumColor(v) {
            this.i.vc = stringToColor(v);
            this._a("heatMaximumColor", colorToString(this.i.vc));
        }
        /**
         * Gets or sets the the pixel extent of the square data points that are rendered.
        */
        get pointExtent() {
            return this.i.um;
        }
        set pointExtent(v) {
            this.i.um = +v;
            this._a("pointExtent", this.i.um);
        }
        /**
         * Represents the current status of the progressive load of the series. It will range from 0 to 100, where 100 is fully loaded.
        */
        get progressiveStatus() {
            return this.i.un;
        }
        set progressiveStatus(v) {
            this.i.un = +v;
            this._a("progressiveStatus", this.i.un);
        }
        /**
         * Raised when the progressive loading state of the series has changed.
        */
        get progressiveLoadStatusChanged() {
            return this._progressiveLoadStatusChanged;
        }
        set progressiveLoadStatusChanged(ev) {
            if (this._progressiveLoadStatusChanged_wrapped !== null) {
                this.i.progressiveLoadStatusChanged = delegateRemove(this.i.progressiveLoadStatusChanged, this._progressiveLoadStatusChanged_wrapped);
                this._progressiveLoadStatusChanged_wrapped = null;
                this._progressiveLoadStatusChanged = null;
            }
            this._progressiveLoadStatusChanged = ev;
            this._progressiveLoadStatusChanged_wrapped = (o, e) => {
                let outerArgs = new IgcProgressiveLoadStatusEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeProgressiveLoadStatusChanged) {
                    this.beforeProgressiveLoadStatusChanged(this, outerArgs);
                }
                if (this._progressiveLoadStatusChanged) {
                    this._progressiveLoadStatusChanged(this, outerArgs);
                }
            };
            this.i.progressiveLoadStatusChanged = delegateCombine(this.i.progressiveLoadStatusChanged, this._progressiveLoadStatusChanged_wrapped);
            ;
        }
    }
    IgcGeographicHighDensityScatterSeriesComponent._observedAttributesIgcGeographicHighDensityScatterSeriesComponent = null;
    IgcGeographicHighDensityScatterSeriesComponent.htmlTagName = "igc-geographic-high-density-scatter-series";
    IgcGeographicHighDensityScatterSeriesComponent._isElementRegistered = false;
    return IgcGeographicHighDensityScatterSeriesComponent;
})();
