import { delegateCombine, delegateRemove } from "igniteui-webcomponents-core";
import { IgcStyleShapeEventArgs } from "igniteui-webcomponents-charts";
import { IgcGeographicShapeSeriesBaseComponent } from "./igc-geographic-shape-series-base-component";
import { GeographicPolylineSeries } from "./GeographicPolylineSeries";
import { getAllPropertyNames, toSpinal } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
import { Style } from "igniteui-webcomponents-core";
/**
 * Series class used for displaying multiple polylines, in a geographic context, for datasources which contain multiple lists of points.
*/
export let IgcGeographicPolylineSeriesComponent = /*@__PURE__*/ (() => {
    class IgcGeographicPolylineSeriesComponent extends IgcGeographicShapeSeriesBaseComponent {
        createImplementation() {
            return new GeographicPolylineSeries();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
            this._styleShape = null;
            this._styleShape_wrapped = null;
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcGeographicPolylineSeriesComponent._observedAttributesIgcGeographicPolylineSeriesComponent == null) {
                let names = getAllPropertyNames(IgcGeographicPolylineSeriesComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicPolylineSeriesComponent._observedAttributesIgcGeographicPolylineSeriesComponent = names;
            }
            return IgcGeographicPolylineSeriesComponent._observedAttributesIgcGeographicPolylineSeriesComponent;
        }
        static register() {
            if (!IgcGeographicPolylineSeriesComponent._isElementRegistered) {
                IgcGeographicPolylineSeriesComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcGeographicPolylineSeriesComponent.htmlTagName, IgcGeographicPolylineSeriesComponent);
            }
        }
        /**
         * Gets whether the current series shows a polyline shape.
        */
        get isPolyline() {
            return this.i.e5;
        }
        /**
         * Gets or sets the fill brush.
        */
        get shapeFill() {
            return this.i.vj ? this.i.vj.fill : null;
        }
        set shapeFill(v) {
            this.ensureShapeStyle();
            this.i.vj.fill = v;
        }
        /**
         * Gets or sets the stroke brush.
        */
        get shapeStroke() {
            return this.i.vj ? this.i.vj.stroke : null;
        }
        set shapeStroke(v) {
            this.ensureShapeStyle();
            this.i.vj.stroke = v;
        }
        /**
         * Gets or sets the stroke thickness.
        */
        get shapeStrokeThickness() {
            return this.i.vj ? this.i.vj.strokeThickness : NaN;
        }
        set shapeStrokeThickness(v) {
            this.ensureShapeStyle();
            this.i.vj.strokeThickness = +v;
            this._a("shapeStrokeThickness", this.i.vj.strokeThickness);
        }
        /**
         * Gets or sets the opacity.
        */
        get shapeOpacity() {
            return this.i.vj ? this.i.vj.opacity : NaN;
        }
        set shapeOpacity(v) {
            this.ensureShapeStyle();
            this.i.vj.opacity = +v;
            this._a("shapeOpacity", this.i.vj.opacity);
        }
        ensureShapeStyle() {
            if (this.i.vj) {
                return;
            }
            this.i.vj = new Style();
        }
        get styleShape() {
            return this._styleShape;
        }
        set styleShape(ev) {
            if (this._styleShape_wrapped !== null) {
                this.i.styleShape = delegateRemove(this.i.styleShape, this._styleShape_wrapped);
                this._styleShape_wrapped = null;
                this._styleShape = null;
            }
            this._styleShape = ev;
            this._styleShape_wrapped = (o, e) => {
                let outerArgs = new IgcStyleShapeEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeStyleShape) {
                    this.beforeStyleShape(this, outerArgs);
                }
                if (this._styleShape) {
                    this._styleShape(this, outerArgs);
                }
            };
            this.i.styleShape = delegateCombine(this.i.styleShape, this._styleShape_wrapped);
            ;
        }
    }
    IgcGeographicPolylineSeriesComponent._observedAttributesIgcGeographicPolylineSeriesComponent = null;
    IgcGeographicPolylineSeriesComponent.htmlTagName = "igc-geographic-polyline-series";
    IgcGeographicPolylineSeriesComponent._isElementRegistered = false;
    return IgcGeographicPolylineSeriesComponent;
})();
