import { delegateCombine, delegateRemove } from "igniteui-webcomponents-core";
import { IgcColorScaleComponent } from "igniteui-webcomponents-charts";
import { IgcTriangulationStatusEventArgs } from "igniteui-webcomponents-core";
import { IgcGeographicXYTriangulatingSeriesComponent } from "./igc-geographic-xy-triangulating-series-component";
import { GeographicScatterAreaSeries } from "./GeographicScatterAreaSeries";
import { getAllPropertyNames, toSpinal } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
/**
 * Series class which draws a colored 2D surface, in a geographic context, based on a triangulation of XY data with numeric values assigned to each point.
*/
export let IgcGeographicScatterAreaSeriesComponent = /*@__PURE__*/ (() => {
    class IgcGeographicScatterAreaSeriesComponent extends IgcGeographicXYTriangulatingSeriesComponent {
        createImplementation() {
            return new GeographicScatterAreaSeries();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
            this._triangulationStatusChanged = null;
            this._triangulationStatusChanged_wrapped = null;
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcGeographicScatterAreaSeriesComponent._observedAttributesIgcGeographicScatterAreaSeriesComponent == null) {
                let names = getAllPropertyNames(IgcGeographicScatterAreaSeriesComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicScatterAreaSeriesComponent._observedAttributesIgcGeographicScatterAreaSeriesComponent = names;
            }
            return IgcGeographicScatterAreaSeriesComponent._observedAttributesIgcGeographicScatterAreaSeriesComponent;
        }
        static register() {
            if (!IgcGeographicScatterAreaSeriesComponent._isElementRegistered) {
                IgcGeographicScatterAreaSeriesComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcGeographicScatterAreaSeriesComponent.htmlTagName, IgcGeographicScatterAreaSeriesComponent);
            }
        }
        /**
         * Gets whether the current series shows an area shape.
        */
        get isArea() {
            return this.i.d9;
        }
        /**
         * The name of the property on each data item containing a numeric value which can be converted to a color by the ColorScale.
        */
        get colorMemberPath() {
            return this.i.u3;
        }
        set colorMemberPath(v) {
            this.i.u3 = v;
        }
        /**
         * The ColorScale used to resolve the color values of points in the series.
        */
        get colorScale() {
            const r = this.i.uy;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                let e = IgcColorScaleComponent._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        }
        set colorScale(v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.uy = null : this.i.uy = v.i;
        }
        /**
         * Gets actual color scale that is set on ColorScale property or default ColorScale
        */
        get actualColorScale() {
            const r = this.i.ux;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                let e = IgcColorScaleComponent._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        }
        set actualColorScale(v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.ux = null : this.i.ux = v.i;
        }
        findByName(name) {
            var baseResult = super.findByName(name);
            if (baseResult) {
                return baseResult;
            }
            if (this.colorScale && this.colorScale.name && this.colorScale.name == name) {
                return this.colorScale;
            }
            if (this.actualColorScale && this.actualColorScale.name && this.actualColorScale.name == name) {
                return this.actualColorScale;
            }
            return null;
        }
        _styling(container, component, parent) {
            super._styling(container, component, parent);
            this._inStyling = true;
            if (this.colorScale && this.colorScale._styling) {
                this.colorScale._styling(container, component, this);
            }
            if (this.actualColorScale && this.actualColorScale._styling) {
                this.actualColorScale._styling(container, component, this);
            }
            this._inStyling = false;
        }
        /**
         * Updates ActualColorScale properties using HostedSeries's ColorScale properties
        
        */
        updateActualColorScale() {
            this.i.u8();
        }
        /**
         * Raised when the status of an ongoing Triangulation has changed.
        */
        get triangulationStatusChanged() {
            return this._triangulationStatusChanged;
        }
        set triangulationStatusChanged(ev) {
            if (this._triangulationStatusChanged_wrapped !== null) {
                this.i.triangulationStatusChanged = delegateRemove(this.i.triangulationStatusChanged, this._triangulationStatusChanged_wrapped);
                this._triangulationStatusChanged_wrapped = null;
                this._triangulationStatusChanged = null;
            }
            this._triangulationStatusChanged = ev;
            this._triangulationStatusChanged_wrapped = (o, e) => {
                let outerArgs = new IgcTriangulationStatusEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeTriangulationStatusChanged) {
                    this.beforeTriangulationStatusChanged(this, outerArgs);
                }
                if (this._triangulationStatusChanged) {
                    this._triangulationStatusChanged(this, outerArgs);
                }
            };
            this.i.triangulationStatusChanged = delegateCombine(this.i.triangulationStatusChanged, this._triangulationStatusChanged_wrapped);
            ;
        }
    }
    IgcGeographicScatterAreaSeriesComponent._observedAttributesIgcGeographicScatterAreaSeriesComponent = null;
    IgcGeographicScatterAreaSeriesComponent.htmlTagName = "igc-geographic-scatter-area-series";
    IgcGeographicScatterAreaSeriesComponent._isElementRegistered = false;
    return IgcGeographicScatterAreaSeriesComponent;
})();
