import { IgcGeographicMapSeriesHostComponent } from "./igc-geographic-map-series-host-component";
import { getAllPropertyNames, toSpinal, ensureBool, ensureEnum, enumToString } from "igniteui-webcomponents-core";
import { IgcShapeDataSource } from "igniteui-webcomponents-core";
import { delegateCombine, delegateRemove } from "igniteui-webcomponents-core";
import { IgcAssigningShapeStyleEventArgs } from "igniteui-webcomponents-charts";
import { IgcAssigningShapeMarkerStyleEventArgs } from "igniteui-webcomponents-charts";
import { ShapeItemSearchMode_$type } from "igniteui-webcomponents-charts";
/**
 * Base class for series which render polygons on a map.
*/
export let IgcGeographicShapeSeriesBaseComponent = /*@__PURE__*/ (() => {
    class IgcGeographicShapeSeriesBaseComponent extends IgcGeographicMapSeriesHostComponent {
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
            this._currData = null;
            this._onImportCompleted = null;
            this._assigningShapeStyle = null;
            this._assigningShapeStyle_wrapped = null;
            this._assigningShapeMarkerStyle = null;
            this._assigningShapeMarkerStyle_wrapped = null;
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcGeographicShapeSeriesBaseComponent._observedAttributesIgcGeographicShapeSeriesBaseComponent == null) {
                let names = getAllPropertyNames(IgcGeographicShapeSeriesBaseComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicShapeSeriesBaseComponent._observedAttributesIgcGeographicShapeSeriesBaseComponent = names;
            }
            return IgcGeographicShapeSeriesBaseComponent._observedAttributesIgcGeographicShapeSeriesBaseComponent;
        }
        /**
         * Gets or sets the string path of the .shp portion of the Shapefile.
        */
        set shapeDataSource(value) {
            this._shapeDataSource = value;
            this.updateShapeDataSource();
        }
        get shapeDataSource() {
            return this._shapeDataSource;
        }
        /**
         * Gets or sets the string path of the .dbf portion of the Shapefile.
        */
        set databaseSource(value) {
            this._databaseSource = value;
            this.updateShapeDataSource();
        }
        get databaseSource() {
            return this._databaseSource;
        }
        onUpdateDataSource(dataSource) {
            if (this._onImportCompleted == null) {
                this._onImportCompleted = (s, e) => {
                    if (this._currData) {
                        this._currData.i.importCompleted = delegateRemove(this._currData.i.importCompleted, this._onImportCompleted);
                        var data = this._currData;
                        this._currData = null;
                        this.i.itemsSource = data.getPointData();
                    }
                };
            }
            if (dataSource && dataSource.getPointData) {
                if (dataSource.count > 0) {
                    return dataSource.getPointData();
                }
                this._currData = dataSource;
                this._currData.i.importCompleted = delegateCombine(this._currData.i.importCompleted, this._onImportCompleted);
                return null;
            }
            return dataSource;
        }
        updateShapeDataSource() {
            if (this._cachedShapeDataSource == null) {
                this._cachedShapeDataSource = new IgcShapeDataSource();
                this.onShapeDataSourceImportCompleted = this.onShapeDataSourceImportCompleted.bind(this);
                this._cachedShapeDataSource.importCompleted = this.onShapeDataSourceImportCompleted;
            }
            this._cachedShapeDataSource.shapefileSource = this._shapeDataSource;
            this._cachedShapeDataSource.databaseSource = this._databaseSource;
            if (this._shapeDataSource && this._databaseSource) {
                this._cachedShapeDataSource.dataBind();
            }
        }
        onShapeDataSourceImportCompleted(s, e) {
            this.dataSource = this._cachedShapeDataSource.getPointData();
        }
        /**
         * The name of the property on ItemsSource items which, for each shape, contains a list of points to be converted to a polygon.
         * To be consistent with the Shapefile technical description, it is expected that each list of points is defined as an IEnumerable of IEnumerable of Point, or in other words, a list of lists of points.
        */
        get shapeMemberPath() {
            return this.i.uy;
        }
        set shapeMemberPath(v) {
            this.i.uy = v;
        }
        /**
         * Gets or sets whether this Shape series should allow custom style overrides of its individual visuals.
        */
        get isCustomShapeStyleAllowed() {
            return this.i.un;
        }
        set isCustomShapeStyleAllowed(v) {
            this.i.un = ensureBool(v);
            this._a("isCustomShapeStyleAllowed", this.i.un);
        }
        /**
         * Gets or sets whether this Shape series should allow custom style overrides of its individual marker visuals.
        */
        get isCustomShapeMarkerStyleAllowed() {
            return this.i.um;
        }
        set isCustomShapeMarkerStyleAllowed(v) {
            this.i.um = ensureBool(v);
            this._a("isCustomShapeMarkerStyleAllowed", this.i.um);
        }
        /**
         * Gets or sets the mode the series will use to find the closest point to the cursor.
        */
        get itemSearchMode() {
            return this.i.uf;
        }
        set itemSearchMode(v) {
            this.i.uf = ensureEnum(ShapeItemSearchMode_$type, v);
            this._a("itemSearchMode", enumToString(ShapeItemSearchMode_$type, this.i.uf));
        }
        /**
         * Gets or sets the threshold to use when searching for items using ItemSearchMode.
        */
        get itemSearchThreshold() {
            return this.i.uq;
        }
        set itemSearchThreshold(v) {
            this.i.uq = +v;
            this._a("itemSearchThreshold", this.i.uq);
        }
        /**
         * Gets or sets the points threshold to use when searching for items using ItemSearchMode.
        */
        get itemSearchPointsThreshold() {
            return this.i.up;
        }
        set itemSearchPointsThreshold(v) {
            this.i.up = +v;
            this._a("itemSearchPointsThreshold", this.i.up);
        }
        /**
         * Set a shapefile datasource to use with the series.
        */
        get shapefileDataSource() {
            const r = this.i.ui;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                let e = new IgcShapeDataSource();
                if (r.$type) {
                    e._implementation = r;
                }
                else {
                    if (e.i.setNativeElement) {
                        e.i.setNativeElement(r);
                    }
                }
                r.externalObject = e;
            }
            return r.externalObject;
        }
        set shapefileDataSource(v) {
            v == null ? this.i.ui = null : this.i.ui = v.i;
        }
        /**
         * The resolution at which to filter out shapes in the series.  For example, if the ShapeFilterResolution is set to 3, then elements with a bounding rectangle smaller than 3 X 3 pixels will be filtered out.
         * In the case of GeographicPolylineSeries, the resolution is compared to either dimension, rather than both.  In other words, a polyline will not be filtered if its height or its width exceeds the value of this property.  Whereas with a ShapeSeries, both the height and the width must exceed the value of this property.
        */
        get shapeFilterResolution() {
            return this.i.uo;
        }
        set shapeFilterResolution(v) {
            this.i.uo = +v;
            this._a("shapeFilterResolution", this.i.uo);
        }
        findByName(name) {
            var baseResult = super.findByName(name);
            if (baseResult) {
                return baseResult;
            }
            if (this.shapefileDataSource && this.shapefileDataSource.name && this.shapefileDataSource.name == name) {
                return this.shapefileDataSource;
            }
            return null;
        }
        /**
         * Event raised when Assigning Shape Style. Note, if using this event, or highlighting, its best to avoid use of ShapeStyle/StyleShape/ShapeStyleSelector.
        */
        get assigningShapeStyle() {
            return this._assigningShapeStyle;
        }
        set assigningShapeStyle(ev) {
            if (this._assigningShapeStyle_wrapped !== null) {
                this.i.assigningShapeStyle = delegateRemove(this.i.assigningShapeStyle, this._assigningShapeStyle_wrapped);
                this._assigningShapeStyle_wrapped = null;
                this._assigningShapeStyle = null;
            }
            this._assigningShapeStyle = ev;
            this._assigningShapeStyle_wrapped = (o, e) => {
                let outerArgs = new IgcAssigningShapeStyleEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeAssigningShapeStyle) {
                    this.beforeAssigningShapeStyle(this, outerArgs);
                }
                if (this._assigningShapeStyle) {
                    this._assigningShapeStyle(this, outerArgs);
                }
            };
            this.i.assigningShapeStyle = delegateCombine(this.i.assigningShapeStyle, this._assigningShapeStyle_wrapped);
            ;
        }
        /**
         * Event raised when Assigning Shape Marker Style
        */
        get assigningShapeMarkerStyle() {
            return this._assigningShapeMarkerStyle;
        }
        set assigningShapeMarkerStyle(ev) {
            if (this._assigningShapeMarkerStyle_wrapped !== null) {
                this.i.assigningShapeMarkerStyle = delegateRemove(this.i.assigningShapeMarkerStyle, this._assigningShapeMarkerStyle_wrapped);
                this._assigningShapeMarkerStyle_wrapped = null;
                this._assigningShapeMarkerStyle = null;
            }
            this._assigningShapeMarkerStyle = ev;
            this._assigningShapeMarkerStyle_wrapped = (o, e) => {
                let outerArgs = new IgcAssigningShapeMarkerStyleEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeAssigningShapeMarkerStyle) {
                    this.beforeAssigningShapeMarkerStyle(this, outerArgs);
                }
                if (this._assigningShapeMarkerStyle) {
                    this._assigningShapeMarkerStyle(this, outerArgs);
                }
            };
            this.i.assigningShapeMarkerStyle = delegateCombine(this.i.assigningShapeMarkerStyle, this._assigningShapeMarkerStyle_wrapped);
            ;
        }
    }
    IgcGeographicShapeSeriesBaseComponent._observedAttributesIgcGeographicShapeSeriesBaseComponent = null;
    return IgcGeographicShapeSeriesBaseComponent;
})();
