import { IgcGeographicMapSeriesHostComponent } from "./igc-geographic-map-series-host-component";
import { getAllPropertyNames, toSpinal } from "igniteui-webcomponents-core";
import { IgcTriangulationDataSource } from "igniteui-webcomponents-core";
/**
 * Base class for geographic series which triangulate XY data prior to rendering.
*/
export let IgcGeographicXYTriangulatingSeriesComponent = /*@__PURE__*/ (() => {
    class IgcGeographicXYTriangulatingSeriesComponent extends IgcGeographicMapSeriesHostComponent {
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
        }
        static get observedAttributes() {
            if (IgcGeographicXYTriangulatingSeriesComponent._observedAttributesIgcGeographicXYTriangulatingSeriesComponent == null) {
                let names = getAllPropertyNames(IgcGeographicXYTriangulatingSeriesComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicXYTriangulatingSeriesComponent._observedAttributesIgcGeographicXYTriangulatingSeriesComponent = names;
            }
            return IgcGeographicXYTriangulatingSeriesComponent._observedAttributesIgcGeographicXYTriangulatingSeriesComponent;
        }
        /**
         * Gets or sets the string path specifying the location of the Itf file.
        */
        set triangulationDataSource(value) {
            this._triangulationDataSource = value;
            this.updateTriangulationDataSource();
        }
        get triangulationDataSource() {
            return this._triangulationDataSource;
        }
        updateTriangulationDataSource() {
            if (this._cachedTriangulationDataSource == null) {
                this._cachedTriangulationDataSource = new IgcTriangulationDataSource();
                this.onTriangulationDataSourceImportCompleted = this.onTriangulationDataSourceImportCompleted.bind(this);
                this._cachedTriangulationDataSource.importCompleted = this.onTriangulationDataSourceImportCompleted;
            }
            this._cachedTriangulationDataSource.source = this._triangulationDataSource;
        }
        onTriangulationDataSourceImportCompleted(s, e) {
            this.dataSource = this._cachedTriangulationDataSource.getPointData();
            this.trianglesSource = this._cachedTriangulationDataSource.getTriangleData();
        }
        /**
     * The name of the property from which to extract the Longitude for each item in the ItemsSource.
    */
        get longitudeMemberPath() {
            return this.i.uh;
        }
        set longitudeMemberPath(v) {
            this.i.uh = v;
        }
        /**
         * The name of the property from which to extract the Latitude for each item in the ItemsSource.
        */
        get latitudeMemberPath() {
            return this.i.uf;
        }
        set latitudeMemberPath(v) {
            this.i.uf = v;
        }
        /**
         * The source of triangulation data.
         * This property is optional.  If it is left as null, the triangulation will be created based on the items in the ItemsSource.  Triangulation is a demanding operation, so the runtime performance will be better when specifying a TriangulationSource, especially when a large number of data items are present.
        */
        get trianglesSource() {
            return this.i.ue;
        }
        set trianglesSource(v) {
            this.i.ue = v;
        }
        /**
         * The name of the property of the TrianglesSource items which, for each triangle, contains the index of the first vertex point in the ItemsSource.
        */
        get triangleVertexMemberPath1() {
            return this.i.uk;
        }
        set triangleVertexMemberPath1(v) {
            this.i.uk = v;
        }
        /**
         * The name of the property of the TrianglesSource items which, for each triangle, contains the index of the second vertex point in the ItemsSource.
        */
        get triangleVertexMemberPath2() {
            return this.i.um;
        }
        set triangleVertexMemberPath2(v) {
            this.i.um = v;
        }
        /**
         * The name of the property of the TrianglesSource items which, for each triangle, contains the index of the third vertex point in the ItemsSource.
        */
        get triangleVertexMemberPath3() {
            return this.i.uo;
        }
        set triangleVertexMemberPath3(v) {
            this.i.uo = v;
        }
    }
    IgcGeographicXYTriangulatingSeriesComponent._observedAttributesIgcGeographicXYTriangulatingSeriesComponent = null;
    return IgcGeographicXYTriangulatingSeriesComponent;
})();
