import { delegateCombine, delegateRemove } from "igniteui-webcomponents-core";
import { IgcImageTilesReadyEventArgs } from "./igc-image-tiles-ready-event-args";
import { IgcImagesChangedEventArgs } from "./igc-images-changed-event-args";
import { IgcCancellingMultiScaleImageEventArgs } from "igniteui-webcomponents-core";
import { IgcDownloadingMultiScaleImageEventArgs } from "igniteui-webcomponents-core";
import { TypeRegistrar } from "igniteui-webcomponents-core";
import { fromRect, toRect, ensureBool } from "igniteui-webcomponents-core";
/**
 * Control class used for displaying multi-scale TileSource imagery.  Designed to be used for background imagery in the IgxGeographicMap.Component
*/
var IgcGeographicMapImagery = /** @class */ /*@__PURE__*/ (function () {
    function IgcGeographicMapImagery() {
        this._imageTilesReady = null;
        this._imageTilesReady_wrapped = null;
        this._imagesChanged = null;
        this._imagesChanged_wrapped = null;
        this._cancellingImage = null;
        this._cancellingImage_wrapped = null;
        this._downloadingImage = null;
        this._downloadingImage_wrapped = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    IgcGeographicMapImagery.prototype.createImplementation = function () {
        return null;
    };
    Object.defineProperty(IgcGeographicMapImagery.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        } /**
                                     * @hidden
                                     */,
        enumerable: false,
        configurable: true
    });
    IgcGeographicMapImagery._createFromInternal = function (internal) {
        if (!internal) {
            return null;
        }
        if (!internal.$type) {
            return null;
        }
        var name = internal.$type.name;
        var externalName = "Igc" + name + "Component";
        if (!TypeRegistrar.isRegistered(externalName)) {
            return null;
        }
        return TypeRegistrar.create(externalName);
    };
    IgcGeographicMapImagery.prototype.onImplementationCreated = function () {
    };
    IgcGeographicMapImagery.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    };
    Object.defineProperty(IgcGeographicMapImagery.prototype, "deferralHandler", {
        /**
         * The deferral handler to use for deferred refreshes.
        */
        get: function () {
            return this.i.deferralHandler;
        },
        set: function (v) {
            this.i.deferralHandler = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicMapImagery.prototype, "windowRect", {
        /**
         * A rectangle representing the portion of the map imagery currently in view.
         * A rectangle at X=0, Y=0 with a Height and Width of 1 implies the entire plotting area is in view.  A Height and Width of .5 would imply that the view is halfway zoomed in.
        */
        get: function () {
            return fromRect(this.i.windowRect);
        },
        set: function (v) {
            this.i.windowRect = toRect(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicMapImagery.prototype, "geographicMap", {
        /**
         * The IgxGeographicMapComponent which is hosting this GeographicMapImagery control.
        */
        get: function () {
            var r = this.i.geographicMap;
            if (r == null) {
                return null;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.geographicMap = null : this.i.geographicMap = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicMapImagery.prototype, "referer", {
        /**
         * Gets or sets the referer sent in the headers of the tile request.
        */
        get: function () {
            return this.i.referer;
        },
        set: function (v) {
            this.i.referer = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicMapImagery.prototype, "isHorizontalWrappingEnabled", {
        /**
         * Gets or sets if horizontal wrapping is enabled for the imagery.
        */
        get: function () {
            return this.i.isHorizontalWrappingEnabled;
        },
        set: function (v) {
            this.i.isHorizontalWrappingEnabled = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicMapImagery.prototype, "userAgent", {
        /**
         * Gets or sets the UserAgent sent in the headers of the tile request.
        */
        get: function () {
            return this.i.userAgent;
        },
        set: function (v) {
            this.i.userAgent = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicMapImagery.prototype, "opacity", {
        get: function () {
            return this.i.opacity;
        },
        set: function (v) {
            this.i.opacity = +v;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicMapImagery.prototype.findByName = function (name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        if (this.geographicMap && this.geographicMap.name && this.geographicMap.name == name) {
            return this.geographicMap;
        }
        return null;
    };
    /**
     * Removes all cached tile Imagery from the
    
    */
    IgcGeographicMapImagery.prototype.clearTileCache = function () {
        this.i.clearTileCache();
    };
    Object.defineProperty(IgcGeographicMapImagery.prototype, "imageTilesReady", {
        /**
         * Event raised when the image tiles have been downloaded.
        */
        get: function () {
            return this._imageTilesReady;
        },
        set: function (ev) {
            var _this = this;
            if (this._imageTilesReady_wrapped !== null) {
                this.i.imageTilesReady = delegateRemove(this.i.imageTilesReady, this._imageTilesReady_wrapped);
                this._imageTilesReady_wrapped = null;
                this._imageTilesReady = null;
            }
            this._imageTilesReady = ev;
            this._imageTilesReady_wrapped = function (o, e) {
                var outerArgs = new IgcImageTilesReadyEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeImageTilesReady) {
                    _this.beforeImageTilesReady(_this, outerArgs);
                }
                if (_this._imageTilesReady) {
                    _this._imageTilesReady(_this, outerArgs);
                }
            };
            this.i.imageTilesReady = delegateCombine(this.i.imageTilesReady, this._imageTilesReady_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicMapImagery.prototype, "imagesChanged", {
        /**
         * Event raised when tile images have changed.
        */
        get: function () {
            return this._imagesChanged;
        },
        set: function (ev) {
            var _this = this;
            if (this._imagesChanged_wrapped !== null) {
                this.i.imagesChanged = delegateRemove(this.i.imagesChanged, this._imagesChanged_wrapped);
                this._imagesChanged_wrapped = null;
                this._imagesChanged = null;
            }
            this._imagesChanged = ev;
            this._imagesChanged_wrapped = function (o, e) {
                var outerArgs = new IgcImagesChangedEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeImagesChanged) {
                    _this.beforeImagesChanged(_this, outerArgs);
                }
                if (_this._imagesChanged) {
                    _this._imagesChanged(_this, outerArgs);
                }
            };
            this.i.imagesChanged = delegateCombine(this.i.imagesChanged, this._imagesChanged_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicMapImagery.prototype, "cancellingImage", {
        /**
         * Event raised when an image is being downloaded.
        */
        get: function () {
            return this._cancellingImage;
        },
        set: function (ev) {
            var _this = this;
            if (this._cancellingImage_wrapped !== null) {
                this.i.cancellingImage = delegateRemove(this.i.cancellingImage, this._cancellingImage_wrapped);
                this._cancellingImage_wrapped = null;
                this._cancellingImage = null;
            }
            this._cancellingImage = ev;
            this._cancellingImage_wrapped = function (o, e) {
                var outerArgs = new IgcCancellingMultiScaleImageEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeCancellingImage) {
                    _this.beforeCancellingImage(_this, outerArgs);
                }
                if (_this._cancellingImage) {
                    _this._cancellingImage(_this, outerArgs);
                }
            };
            this.i.cancellingImage = delegateCombine(this.i.cancellingImage, this._cancellingImage_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicMapImagery.prototype, "downloadingImage", {
        /**
         * Event raised when an image is being downloaded.
        */
        get: function () {
            return this._downloadingImage;
        },
        set: function (ev) {
            var _this = this;
            if (this._downloadingImage_wrapped !== null) {
                this.i.downloadingImage = delegateRemove(this.i.downloadingImage, this._downloadingImage_wrapped);
                this._downloadingImage_wrapped = null;
                this._downloadingImage = null;
            }
            this._downloadingImage = ev;
            this._downloadingImage_wrapped = function (o, e) {
                var outerArgs = new IgcDownloadingMultiScaleImageEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeDownloadingImage) {
                    _this.beforeDownloadingImage(_this, outerArgs);
                }
                if (_this._downloadingImage) {
                    _this._downloadingImage(_this, outerArgs);
                }
            };
            this.i.downloadingImage = delegateCombine(this.i.downloadingImage, this._downloadingImage_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    return IgcGeographicMapImagery;
}());
export { IgcGeographicMapImagery };
