import { __extends } from "tslib";
import { MarkerType_$type } from "igniteui-webcomponents-charts";
import { MarkerOutlineMode_$type } from "igniteui-webcomponents-charts";
import { MarkerFillMode_$type } from "igniteui-webcomponents-charts";
import { IgcGeographicMapSeriesHostComponent } from "./igc-geographic-map-series-host-component";
import { getAllPropertyNames, toSpinal, ensureEnum, enumToString, brushToString, stringToBrush } from "igniteui-webcomponents-core";
/**
 * Base class for creating marker series in a IgxGeographicMap.Component
*/
var IgcGeographicMarkerSeriesComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcGeographicMarkerSeriesComponent, _super);
    function IgcGeographicMarkerSeriesComponent() {
        return _super.call(this) || this;
    }
    Object.defineProperty(IgcGeographicMarkerSeriesComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicMarkerSeriesComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcGeographicMarkerSeriesComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcGeographicMarkerSeriesComponent, "observedAttributes", {
        get: function () {
            if (IgcGeographicMarkerSeriesComponent._observedAttributesIgcGeographicMarkerSeriesComponent == null) {
                var names = getAllPropertyNames(IgcGeographicMarkerSeriesComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicMarkerSeriesComponent._observedAttributesIgcGeographicMarkerSeriesComponent = names;
            }
            return IgcGeographicMarkerSeriesComponent._observedAttributesIgcGeographicMarkerSeriesComponent;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicMarkerSeriesComponent.prototype, "markerType", {
        /**
         * Gets or sets the marker type for the current series object.
         * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
        */
        get: function () {
            return this.i.uf;
        },
        set: function (v) {
            this.i.uf = ensureEnum(MarkerType_$type, v);
            this._a("markerType", enumToString(MarkerType_$type, this.i.uf));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicMarkerSeriesComponent.prototype, "markerThickness", {
        /**
         * Gets or sets thickness of the marker outline
        */
        get: function () {
            return this.i.ug;
        },
        set: function (v) {
            this.i.ug = +v;
            this._a("markerThickness", this.i.ug);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicMarkerSeriesComponent.prototype, "markerOutlineMode", {
        /**
         * Gets or sets whether the marker outline is based on the marker brush of the series rather than the marker outlines collection.
        */
        get: function () {
            return this.i.ue;
        },
        set: function (v) {
            this.i.ue = ensureEnum(MarkerOutlineMode_$type, v);
            this._a("markerOutlineMode", enumToString(MarkerOutlineMode_$type, this.i.ue));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicMarkerSeriesComponent.prototype, "markerFillMode", {
        /**
         * Gets or sets whether the marker fill is based on the marker outline of the series rather than the marker brushes collection.
        */
        get: function () {
            return this.i.ud;
        },
        set: function (v) {
            this.i.ud = ensureEnum(MarkerFillMode_$type, v);
            this._a("markerFillMode", enumToString(MarkerFillMode_$type, this.i.ud));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicMarkerSeriesComponent.prototype, "markerTemplate", {
        /**
         * Gets or sets the MarkerTemplate for the current series object.
        */
        get: function () {
            return this.i.uv;
        },
        set: function (v) {
            this.i.uv = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicMarkerSeriesComponent.prototype, "markerBrush", {
        /**
         * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
        */
        get: function () {
            return brushToString(this.i.u9);
        },
        set: function (v) {
            this.i.u9 = stringToBrush(v);
            this._a("markerBrush", brushToString(this.i.u9));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicMarkerSeriesComponent.prototype, "markerOutline", {
        /**
         * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
        */
        get: function () {
            return brushToString(this.i.va);
        },
        set: function (v) {
            this.i.va = stringToBrush(v);
            this._a("markerOutline", brushToString(this.i.va));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicMarkerSeriesComponent.prototype, "maximumMarkers", {
        /**
         * Gets or sets the maximum number of markerItems displayed by the current series.
         * If more than the specified number of markerItems are visible, the series will automatically
         * choose a representative set.
        */
        get: function () {
            return this.i.uh;
        },
        set: function (v) {
            this.i.uh = +v;
            this._a("maximumMarkers", this.i.uh);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicMarkerSeriesComponent.prototype, "actualMarkerTemplate", {
        /**
         * Gets the effective marker template for the current series object.
        */
        get: function () {
            return this.i.uu;
        },
        set: function (v) {
            this.i.uu = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicMarkerSeriesComponent.prototype, "actualMarkerBrush", {
        /**
         * Gets the effective marker brush for the current series object.
        */
        get: function () {
            return brushToString(this.i.u7);
        },
        set: function (v) {
            this.i.u7 = stringToBrush(v);
            this._a("actualMarkerBrush", brushToString(this.i.u7));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicMarkerSeriesComponent.prototype, "actualMarkerOutline", {
        /**
         * Gets the effective marker outline for the current series object.
        */
        get: function () {
            return brushToString(this.i.u8);
        },
        set: function (v) {
            this.i.u8 = stringToBrush(v);
            this._a("actualMarkerOutline", brushToString(this.i.u8));
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicMarkerSeriesComponent._observedAttributesIgcGeographicMarkerSeriesComponent = null;
    return IgcGeographicMarkerSeriesComponent;
}(IgcGeographicMapSeriesHostComponent));
export { IgcGeographicMarkerSeriesComponent };
