import { __extends } from "tslib";
import { delegateCombine, delegateRemove } from "igniteui-webcomponents-core";
import { IgcImageTilesReadyEventArgs } from "./igc-image-tiles-ready-event-args";
import { IgcGeographicShapeSeriesBaseComponent } from "./igc-geographic-shape-series-base-component";
import { GeographicTileSeries } from "./GeographicTileSeries";
import { getAllPropertyNames, toSpinal } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
/**
 * Series class used for displaying a tile set, and using shapes to define the areas that should be rendered.
*/
var IgcGeographicTileSeriesComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcGeographicTileSeriesComponent, _super);
    function IgcGeographicTileSeriesComponent() {
        var _this = _super.call(this) || this;
        _this._imageTilesReady = null;
        _this._imageTilesReady_wrapped = null;
        return _this;
    }
    IgcGeographicTileSeriesComponent.prototype.createImplementation = function () {
        return new GeographicTileSeries();
    };
    Object.defineProperty(IgcGeographicTileSeriesComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicTileSeriesComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcGeographicTileSeriesComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcGeographicTileSeriesComponent, "observedAttributes", {
        get: function () {
            if (IgcGeographicTileSeriesComponent._observedAttributesIgcGeographicTileSeriesComponent == null) {
                var names = getAllPropertyNames(IgcGeographicTileSeriesComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicTileSeriesComponent._observedAttributesIgcGeographicTileSeriesComponent = names;
            }
            return IgcGeographicTileSeriesComponent._observedAttributesIgcGeographicTileSeriesComponent;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicTileSeriesComponent.register = function () {
        if (!IgcGeographicTileSeriesComponent._isElementRegistered) {
            IgcGeographicTileSeriesComponent._isElementRegistered = true;
            RegisterElementHelper.registerElement(IgcGeographicTileSeriesComponent.htmlTagName, IgcGeographicTileSeriesComponent);
        }
    };
    Object.defineProperty(IgcGeographicTileSeriesComponent.prototype, "isTile", {
        /**
         * Gets whether the current series shows a tile imagery.
        */
        get: function () {
            return this.i.fh;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicTileSeriesComponent.prototype, "tileImagery", {
        /**
         * The MapImagery which is used to provide the tiles for display.
        */
        get: function () {
            var r = this.i.vd;
            if (r == null) {
                return null;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.vd = null : this.i.vd = v.i;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicTileSeriesComponent.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.tileImagery && this.tileImagery.name && this.tileImagery.name == name) {
            return this.tileImagery;
        }
        return null;
    };
    /**
     * Removes all cached tile Imagery from the
    
    */
    IgcGeographicTileSeriesComponent.prototype.clearTileCache = function () {
        this.i.vh();
    };
    Object.defineProperty(IgcGeographicTileSeriesComponent.prototype, "imageTilesReady", {
        /**
         * This event is fired whenever the image tiles transition from a loading state (e.g. some are fading in) to a loaded state.
        */
        get: function () {
            return this._imageTilesReady;
        },
        set: function (ev) {
            var _this = this;
            if (this._imageTilesReady_wrapped !== null) {
                this.i.imageTilesReady = delegateRemove(this.i.imageTilesReady, this._imageTilesReady_wrapped);
                this._imageTilesReady_wrapped = null;
                this._imageTilesReady = null;
            }
            this._imageTilesReady = ev;
            this._imageTilesReady_wrapped = function (o, e) {
                var outerArgs = new IgcImageTilesReadyEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeImageTilesReady) {
                    _this.beforeImageTilesReady(_this, outerArgs);
                }
                if (_this._imageTilesReady) {
                    _this._imageTilesReady(_this, outerArgs);
                }
            };
            this.i.imageTilesReady = delegateCombine(this.i.imageTilesReady, this._imageTilesReady_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicTileSeriesComponent._observedAttributesIgcGeographicTileSeriesComponent = null;
    IgcGeographicTileSeriesComponent.htmlTagName = "igc-geographic-tile-series";
    IgcGeographicTileSeriesComponent._isElementRegistered = false;
    return IgcGeographicTileSeriesComponent;
}(IgcGeographicShapeSeriesBaseComponent));
export { IgcGeographicTileSeriesComponent };
