import { __extends } from "tslib";
import { IgcGeographicMapSeriesHostComponent } from "./igc-geographic-map-series-host-component";
import { getAllPropertyNames, toSpinal } from "igniteui-webcomponents-core";
import { IgcTriangulationDataSource } from "igniteui-webcomponents-core";
/**
 * Base class for geographic series which triangulate XY data prior to rendering.
*/
var IgcGeographicXYTriangulatingSeriesComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcGeographicXYTriangulatingSeriesComponent, _super);
    function IgcGeographicXYTriangulatingSeriesComponent() {
        return _super.call(this) || this;
    }
    Object.defineProperty(IgcGeographicXYTriangulatingSeriesComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicXYTriangulatingSeriesComponent, "observedAttributes", {
        get: function () {
            if (IgcGeographicXYTriangulatingSeriesComponent._observedAttributesIgcGeographicXYTriangulatingSeriesComponent == null) {
                var names = getAllPropertyNames(IgcGeographicXYTriangulatingSeriesComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicXYTriangulatingSeriesComponent._observedAttributesIgcGeographicXYTriangulatingSeriesComponent = names;
            }
            return IgcGeographicXYTriangulatingSeriesComponent._observedAttributesIgcGeographicXYTriangulatingSeriesComponent;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicXYTriangulatingSeriesComponent.prototype, "triangulationDataSource", {
        get: function () {
            return this._triangulationDataSource;
        },
        /**
         * Gets or sets the string path specifying the location of the Itf file.
        */
        set: function (value) {
            this._triangulationDataSource = value;
            this.updateTriangulationDataSource();
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicXYTriangulatingSeriesComponent.prototype.updateTriangulationDataSource = function () {
        if (this._cachedTriangulationDataSource == null) {
            this._cachedTriangulationDataSource = new IgcTriangulationDataSource();
            this.onTriangulationDataSourceImportCompleted = this.onTriangulationDataSourceImportCompleted.bind(this);
            this._cachedTriangulationDataSource.importCompleted = this.onTriangulationDataSourceImportCompleted;
        }
        this._cachedTriangulationDataSource.source = this._triangulationDataSource;
    };
    IgcGeographicXYTriangulatingSeriesComponent.prototype.onTriangulationDataSourceImportCompleted = function (s, e) {
        this.dataSource = this._cachedTriangulationDataSource.getPointData();
        this.trianglesSource = this._cachedTriangulationDataSource.getTriangleData();
    };
    Object.defineProperty(IgcGeographicXYTriangulatingSeriesComponent.prototype, "longitudeMemberPath", {
        /**
     * The name of the property from which to extract the Longitude for each item in the ItemsSource.
    */
        get: function () {
            return this.i.uh;
        },
        set: function (v) {
            this.i.uh = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicXYTriangulatingSeriesComponent.prototype, "latitudeMemberPath", {
        /**
         * The name of the property from which to extract the Latitude for each item in the ItemsSource.
        */
        get: function () {
            return this.i.uf;
        },
        set: function (v) {
            this.i.uf = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicXYTriangulatingSeriesComponent.prototype, "trianglesSource", {
        /**
         * The source of triangulation data.
         * This property is optional.  If it is left as null, the triangulation will be created based on the items in the ItemsSource.  Triangulation is a demanding operation, so the runtime performance will be better when specifying a TriangulationSource, especially when a large number of data items are present.
        */
        get: function () {
            return this.i.ue;
        },
        set: function (v) {
            this.i.ue = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicXYTriangulatingSeriesComponent.prototype, "triangleVertexMemberPath1", {
        /**
         * The name of the property of the TrianglesSource items which, for each triangle, contains the index of the first vertex point in the ItemsSource.
        */
        get: function () {
            return this.i.uk;
        },
        set: function (v) {
            this.i.uk = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicXYTriangulatingSeriesComponent.prototype, "triangleVertexMemberPath2", {
        /**
         * The name of the property of the TrianglesSource items which, for each triangle, contains the index of the second vertex point in the ItemsSource.
        */
        get: function () {
            return this.i.um;
        },
        set: function (v) {
            this.i.um = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicXYTriangulatingSeriesComponent.prototype, "triangleVertexMemberPath3", {
        /**
         * The name of the property of the TrianglesSource items which, for each triangle, contains the index of the third vertex point in the ItemsSource.
        */
        get: function () {
            return this.i.uo;
        },
        set: function (v) {
            this.i.uo = v;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicXYTriangulatingSeriesComponent._observedAttributesIgcGeographicXYTriangulatingSeriesComponent = null;
    return IgcGeographicXYTriangulatingSeriesComponent;
}(IgcGeographicMapSeriesHostComponent));
export { IgcGeographicXYTriangulatingSeriesComponent };
