import { IgcSubDomainsCollection } from "./igc-sub-domains-collection";
import { BingMapsImageryStyle } from "./BingMapsImageryStyle";
import { IgcGeographicMapImagery } from "./igc-geographic-map-imagery";
import { BingMapsMapImagery as BingMapsMapImagery_internal } from "./BingMapsMapImagery";
/**
 * UI element class used to display BingMapsMap imagery in the IgxGeographicMap.Component
*/
export declare class IgcBingMapsMapImagery extends IgcGeographicMapImagery {
    protected createImplementation(): BingMapsMapImagery_internal;
    /**
                                 * @hidden
                                 */
    get i(): BingMapsMapImagery_internal;
    constructor();
    /**
     * Gets a status whether the Bing Maps service is initialized.
    */
    get isInitialized(): boolean;
    set isInitialized(v: boolean);
    /**
     * Gets or sets whether the Bing Maps service should be auto-initialized upon valid property values.
    */
    get isDeferredLoad(): boolean;
    set isDeferredLoad(v: boolean);
    /**
     * Gets or sets the map tile image uri.
    */
    get tilePath(): string;
    set tilePath(v: string);
    /**
     * Gets or sets the actual map tile image uri.
    */
    get actualTilePath(): string;
    set actualTilePath(v: string);
    private _subDomains;
    /**
     * Gets or sets the collection of image uri subdomains.
    */
    get subDomains(): IgcSubDomainsCollection;
    set subDomains(v: IgcSubDomainsCollection);
    private _actualSubDomains;
    /**
     * Gets or sets the actual collection of image uri subdomains.
    */
    get actualSubDomains(): IgcSubDomainsCollection;
    set actualSubDomains(v: IgcSubDomainsCollection);
    /**
     * Gets or sets the Bing Imagery Rest Uri.
    */
    get bingImageryRestUri(): string;
    set bingImageryRestUri(v: string);
    /**
     * Gets or sets the Actual Bing Imagery Rest Uri.
    */
    get actualBingImageryRestUri(): string;
    set actualBingImageryRestUri(v: string);
    /**
     * Gets or sets the culture name for this tile source.
    */
    get cultureName(): string;
    set cultureName(v: string);
    /**
     * Gets or sets an API key required by the Bing Maps imagery service.
     * This key must be obtained from the http://www.bingmapsportal.com website.
    */
    get apiKey(): string;
    set apiKey(v: string);
    /**
     * Gets or sets a map style of the Bing Maps imagery tiles.
     * For example: Aerial, AerialWithLabels, or Road map style.
    */
    get imageryStyle(): BingMapsImageryStyle;
    set imageryStyle(v: BingMapsImageryStyle);
    /**
     * Will Connect to the Bing Rest API and retrieve the required TilePath and Subdomains from the service.  This requires a valid API key to already be set.
    
    */
    requestMapSettings(): void;
}
