import { IgcSeriesComponent } from "igniteui-webcomponents-charts";
import { IgcSeriesViewerComponent } from "igniteui-webcomponents-charts";
import { IgRect } from "igniteui-webcomponents-core";
import { IgPoint } from "igniteui-webcomponents-core";
import { XamGeographicMap } from './XamGeographicMap';
import { IgcSeriesCollection } from "igniteui-webcomponents-charts";
import { IgcNumericXAxisComponent } from "igniteui-webcomponents-charts";
import { IgcNumericYAxisComponent } from "igniteui-webcomponents-charts";
import { IgcImageTilesReadyEventArgs } from './igc-image-tiles-ready-event-args';
import { IgcGeographicMapImagery } from './igc-geographic-map-imagery';
import { MapResizeBehavior } from './MapResizeBehavior';
import { MapBackgroundTilingMode } from './MapBackgroundTilingMode';
export declare class IgcGeographicMapComponent extends IgcSeriesViewerComponent {
    contentSeries: IgcSeriesComponent[];
    private _height;
    private _width;
    set height(value: string);
    get height(): string;
    set width(value: string);
    get width(): string;
    notifyContainerResized(): void;
    /**
     * Gets or sets the legend used for the current chart.
    */
    get legend(): any;
    set legend(v: any);
    /**
     * The series actually present in the chart. Do not directly modify this array.
     * This array's contents can be modified by causing Angular to reproject the child content.
     * Or adding and removing series from the manual series collection on the series property.
     */
    actualSeries: IgcSeriesComponent[];
    private _container;
    private _series;
    /**
     * A collection or manually added series for the chart.
    */
    get series(): IgcSeriesCollection;
    private _renderer;
    constructor();
    destroy(): void;
    private _wrapper;
    protected createImplementation(): XamGeographicMap;
    private _chart;
    private _dataSource;
    set dataSource(value: any);
    get dataSource(): any;
    bindData(): void;
    private updateContentChildren;
    private _seriesAdapter;
    private _disconnected;
    disconnectedCallback(): void;
    connectedCallback(): void;
    afterContentInit(): void;
    private _ensureTooltipCreated;
    private _defaultTooltips;
    private _ensureDefaultTooltip;
    private _onDefaultTooltipsReady;
    private createTooltip;
    /**
     * An imagery to display behind all series, inside the viewport of the IgxGeographicMapComponent control.
    */
    get backgroundContent(): IgcGeographicMapImagery;
    set backgroundContent(v: IgcGeographicMapImagery);
    /**
                             * @hidden
                             */
    get i(): XamGeographicMap;
    private static _observedAttributesIgcGeographicMapComponent;
    static get observedAttributes(): string[];
    static htmlTagName: string;
    protected static _isElementRegistered: boolean;
    static register(): void;
    /**
 * Gets or sets zoomability of the current control
*/
    get zoomable(): boolean;
    set zoomable(v: boolean);
    /**
     * Gets or sets the behavior to use during resize.
    */
    get resizeBehavior(): MapResizeBehavior;
    set resizeBehavior(v: MapResizeBehavior);
    /**
     * Gets or sets if the map should horizontally wrap.
    */
    get isHorizontalWrappingEnabled(): boolean;
    set isHorizontalWrappingEnabled(v: boolean);
    /**
     * Gets or sets if the map should horizontally wrap.
    */
    get backgroundTilingMode(): MapBackgroundTilingMode;
    set backgroundTilingMode(v: MapBackgroundTilingMode);
    /**
     * Gets or sets whether to use the uncoerced world rect to constrain the zoom bounds.
    */
    get useWorldRectForZoomBounds(): boolean;
    set useWorldRectForZoomBounds(v: boolean);
    /**
     * Gets or sets whether skip resetting the zoom when the world rect changes.
    */
    get suppressZoomResetOnWorldRectChange(): boolean;
    set suppressZoomResetOnWorldRectChange(v: boolean);
    /**
     * Gets or sets the world bounding rectangle.
    */
    get worldRect(): IgRect;
    set worldRect(v: IgRect);
    /**
     * Gets the actual value of the WorldRect.
    */
    get actualWorldRect(): IgRect;
    set actualWorldRect(v: IgRect);
    /**
     * The X-axis for this IgxGeographicMap.Component
     * Under normal circumstances, this property should not be set in application code.  By default, it will be set to a numeric axis with a spherical mercator scaler.
    */
    get xAxis(): IgcNumericXAxisComponent;
    set xAxis(v: IgcNumericXAxisComponent);
    /**
     * The Y-axis for this IgxGeographicMap.Component
     * Under normal circumstances, this property should not be set in application code.  By default, it will be set to a numeric axis with a spherical mercator scaler.
    */
    get yAxis(): IgcNumericYAxisComponent;
    set yAxis(v: IgcNumericYAxisComponent);
    /**
     * Indicates if this SeriesViewer is a map.
    */
    get isMap(): boolean;
    /**
     * A number between 0 and 1 determining the scale of the horizontal/vertical zoom.
     * This property is effectively a shortcut to the Width/Height of the WindowRect property.
    */
    get windowScale(): number;
    set windowScale(v: number);
    /**
     * A number between 0 and 1 determining the scale of the horizontal/vertical zoom.
     * This property is effectively a shortcut to the Width/Height of the ActualWindowRect property.
    */
    get actualWindowScale(): number;
    set actualWindowScale(v: number);
    /**
     * Gets whether or not the control is ready for zooming
    */
    get zoomIsReady(): boolean;
    findByName(name: string): any;
    protected _styling(container: any, component: any, parent?: any): void;
    /**
 * Gets current world rect in geographic coordinates

*/
    getCurrentActualWorldRect(): IgRect;
    /**
     * Given the current plot area of the control and a geographic region, get the WindowRect that would encompass that geographic region.
    
    * @param geographic  * The geographic area.
    */
    getZoomRectFromGeoRect(geographic: IgRect): IgRect;
    /**
     * Updates zoom window using window coordinates
    
    */
    updateZoomWindow(zoomWindow: IgRect): void;
    /**
     * Updates world rect in geographic coordinates
    
    */
    updateWorldRect(worldRect: IgRect): void;
    /**
     * Given the current plot area of the control and a geographic region, get the WindowRect that would encompass that geographic region.
    
    * @param geographic  * The geographic area.
    */
    getZoomFromGeographicRect(geographic: IgRect): IgRect;
    convertGeographicToZoom(geographic: IgRect, extraPixelPadding: number): IgRect;
    getZoomFromGeographicPoints(northWest: IgPoint, southEast: IgPoint): IgRect;
    /**
     * Given a WindowRect and the current plot area, get the geographic region represented by that WindowRect.
    
    * @param windowRect  * The zoom area.
    */
    getGeographicFromZoom(windowRect: IgRect): IgRect;
    /**
     * Convert a pixel-based coordinate to a geographic coordinate.
    
    * @param pixelCoordinate  * A pixel-based coordinate
    */
    getGeographicPoint(pixelCoordinate: IgPoint): IgPoint;
    /**
     * Convert a geographic coordinate to a pixel-based coordinate.
    
    * @param geographicCoordinate  * A geographic coordinate
    */
    getPixelPoint(geographicCoordinate: IgPoint): IgPoint;
    /**
     * Convert a geographic coordinate to a pixel-based coordinate.
    
    * @param geographicCoordinate  * A geographic coordinate
    */
    getWindowPoint(geographicCoordinate: IgPoint): IgPoint;
    /**
     * Removes all cached tile images from the map imagery assigned to the map's background content.
    
    */
    clearTileCache(): void;
    /**
     * Notifies the chart that the CSS styles in effect have been updated.
    
    */
    styleUpdated(): void;
    /**
     * Gets actual window scale for horizontal dimension of the control
    
    */
    getActualWindowScaleHorizontal(): number;
    /**
     * Gets actual window scale for vertical dimension of the control
    
    */
    getActualWindowScaleVertical(): number;
    /**
     * Calls for a deferred refresh to the GeographicMap's background.
    
    */
    deferredRefresh(): void;
    /**
     * Returns the chart visuals expressed as a ChartVisualData object.
    
    */
    exportVisualData(): any;
    /**
     * Zoom in to the geographic region specified, when possible (may need to wait for map to be initialized).
    
    * @param geographic  * The geographic region to zoom to.
    */
    zoomToGeographic(geographic: IgRect): void;
    private _imageTilesReady;
    private _imageTilesReady_wrapped;
    /**
     * This event is fired whenever the image tiles transition from a loading state (e.g. some are fading in) to a loaded state.
    */
    get imageTilesReady(): (s: IgcGeographicMapComponent, e: IgcImageTilesReadyEventArgs) => void;
    set imageTilesReady(ev: (s: IgcGeographicMapComponent, e: IgcImageTilesReadyEventArgs) => void);
}
