import { IgRect } from "igniteui-webcomponents-core";
import { IgcGeographicMapComponent } from "./igc-geographic-map-component";
import { IgcImageTilesReadyEventArgs } from "./igc-image-tiles-ready-event-args";
import { IgcImagesChangedEventArgs } from "./igc-images-changed-event-args";
import { IgcCancellingMultiScaleImageEventArgs } from "igniteui-webcomponents-core";
import { IgcDownloadingMultiScaleImageEventArgs } from "igniteui-webcomponents-core";
import { GeographicMapImagery as GeographicMapImagery_internal } from "./GeographicMapImagery";
import { IMapRenderDeferralHandler } from "igniteui-webcomponents-core";
/**
 * Control class used for displaying multi-scale TileSource imagery.  Designed to be used for background imagery in the IgxGeographicMap.Component
*/
export declare abstract class IgcGeographicMapImagery {
    protected createImplementation(): GeographicMapImagery_internal;
    protected _implementation: any;
    /**
     * @hidden
     */
    get i(): GeographicMapImagery_internal; /**
                                 * @hidden
                                 */
    static _createFromInternal(internal: any): IgcGeographicMapImagery;
    private onImplementationCreated;
    constructor();
    protected _provideImplementation(i: any): void;
    /**
     * The deferral handler to use for deferred refreshes.
    */
    get deferralHandler(): IMapRenderDeferralHandler;
    set deferralHandler(v: IMapRenderDeferralHandler);
    /**
     * A rectangle representing the portion of the map imagery currently in view.
     * A rectangle at X=0, Y=0 with a Height and Width of 1 implies the entire plotting area is in view.  A Height and Width of .5 would imply that the view is halfway zoomed in.
    */
    get windowRect(): IgRect;
    set windowRect(v: IgRect);
    /**
     * The IgxGeographicMapComponent which is hosting this GeographicMapImagery control.
    */
    get geographicMap(): IgcGeographicMapComponent;
    set geographicMap(v: IgcGeographicMapComponent);
    /**
     * Gets or sets the referer sent in the headers of the tile request.
    */
    get referer(): string;
    set referer(v: string);
    /**
     * Gets or sets if horizontal wrapping is enabled for the imagery.
    */
    get isHorizontalWrappingEnabled(): boolean;
    set isHorizontalWrappingEnabled(v: boolean);
    /**
     * Gets or sets the UserAgent sent in the headers of the tile request.
    */
    get userAgent(): string;
    set userAgent(v: string);
    get opacity(): number;
    set opacity(v: number);
    findByName(name: string): any;
    /**
     * Removes all cached tile Imagery from the
    
    */
    clearTileCache(): void;
    private _imageTilesReady;
    private _imageTilesReady_wrapped;
    /**
     * Event raised when the image tiles have been downloaded.
    */
    get imageTilesReady(): (s: IgcGeographicMapImagery, e: IgcImageTilesReadyEventArgs) => void;
    set imageTilesReady(ev: (s: IgcGeographicMapImagery, e: IgcImageTilesReadyEventArgs) => void);
    private _imagesChanged;
    private _imagesChanged_wrapped;
    /**
     * Event raised when tile images have changed.
    */
    get imagesChanged(): (s: IgcGeographicMapImagery, e: IgcImagesChangedEventArgs) => void;
    set imagesChanged(ev: (s: IgcGeographicMapImagery, e: IgcImagesChangedEventArgs) => void);
    private _cancellingImage;
    private _cancellingImage_wrapped;
    /**
     * Event raised when an image is being downloaded.
    */
    get cancellingImage(): (s: IgcGeographicMapImagery, e: IgcCancellingMultiScaleImageEventArgs) => void;
    set cancellingImage(ev: (s: IgcGeographicMapImagery, e: IgcCancellingMultiScaleImageEventArgs) => void);
    private _downloadingImage;
    private _downloadingImage_wrapped;
    /**
     * Event raised when an image is being downloaded.
    */
    get downloadingImage(): (s: IgcGeographicMapImagery, e: IgcDownloadingMultiScaleImageEventArgs) => void;
    set downloadingImage(ev: (s: IgcGeographicMapImagery, e: IgcDownloadingMultiScaleImageEventArgs) => void);
}
