import { IgcSizeScaleComponent } from "igniteui-webcomponents-charts";
import { IgcBrushScaleComponent } from "igniteui-webcomponents-charts";
import { ScatterItemSearchMode } from "igniteui-webcomponents-charts";
import { IgcAssigningScatterStyleEventArgs } from "igniteui-webcomponents-charts";
import { IgcAssigningScatterMarkerStyleEventArgs } from "igniteui-webcomponents-charts";
import { IgcGeographicMarkerSeriesComponent } from "./igc-geographic-marker-series-component";
import { GeographicProportionalSymbolSeries } from "./GeographicProportionalSymbolSeries";
/**
 * Series class for a geographic map with points marked at given locations.
 * This is the geographic equivalent of a ScatterSeries.
*/
export declare class IgcGeographicProportionalSymbolSeriesComponent extends IgcGeographicMarkerSeriesComponent {
    protected createImplementation(): GeographicProportionalSymbolSeries;
    /**
                                 * @hidden
                                 */
    get i(): GeographicProportionalSymbolSeries;
    constructor();
    connectedCallback(): void;
    disconnectedCallback(): void;
    private static _observedAttributesIgcGeographicProportionalSymbolSeriesComponent;
    static get observedAttributes(): string[];
    static htmlTagName: string;
    protected static _isElementRegistered: boolean;
    static register(): void;
    /**
     * Gets whether the series has only marker as visuals
    */
    get hasOnlyMarkers(): boolean;
    /**
     * The name of the property of ItemsSource items which contains the latitude coordinate of the symbol.
    */
    get latitudeMemberPath(): string;
    set latitudeMemberPath(v: string);
    /**
     * The name of the property of ItemsSource items which contains the longitude coordinate of the symbol.
    */
    get longitudeMemberPath(): string;
    set longitudeMemberPath(v: string);
    /**
     * Gets or sets the radius mapping property for the current series object.
    */
    get radiusMemberPath(): string;
    set radiusMemberPath(v: string);
    /**
     * Gets or sets the radius size scale for the bubbles.
    */
    get radiusScale(): IgcSizeScaleComponent;
    set radiusScale(v: IgcSizeScaleComponent);
    /**
     * Gets or sets the Label mapping property for the current series object.
    */
    get labelMemberPath(): string;
    set labelMemberPath(v: string);
    /**
     * Gets or sets the fill mapping property for the current series object.
    */
    get fillMemberPath(): string;
    set fillMemberPath(v: string);
    /**
     * Gets or sets the brush scale for the marker brush.
    */
    get fillScale(): IgcBrushScaleComponent;
    set fillScale(v: IgcBrushScaleComponent);
    /**
     * Gets or sets the whether or not the FillScale uses global values of FillMemberPath of multiple series.
     * This setting applies only if multiple series are using the same FillScale.
    */
    get fillScaleUseGlobalValues(): boolean;
    set fillScaleUseGlobalValues(v: boolean);
    /**
     * Gets or sets whether or not the marker outline should use FillScale like the marker fill does.
     * This setting applies only if the current series has a FillScale set and it overrides MarkerOutline setting.
    */
    get markerOutlineUsesFillScale(): boolean;
    set markerOutlineUsesFillScale(v: boolean);
    /**
     * Gets or sets brightness of the marker outline. Using negative value will change marker outline to darker color and positive value will change marker outline to brighter color
     * Note you can use any values between minimum value of -1 (darkest outline) and maximum value of 1 (brightest outline)
    */
    get markerOutlineBrightness(): number;
    set markerOutlineBrightness(v: number);
    /**
     * Gets or sets brightness of the marker fill. Using negative value will change marker fill to darker color and positive value will change marker fill to brighter color
     * Note you can use any values between minimum value of -1 (darkest fill) and maximum value of 1 (brightest fill)
    */
    get markerBrushBrightness(): number;
    set markerBrushBrightness(v: number);
    /**
     * Gets or sets the whether or not the RadiusScale uses global values of RadiusMemberPath of multiple series.
     * This setting applies only if multiple series are using the same RadiusScale.
    */
    get radiusScaleUseGlobalValues(): boolean;
    set radiusScaleUseGlobalValues(v: boolean);
    /**
     * Gets or sets whether this Scatter series should allow custom style overrides of its individual visuals.
    */
    get isCustomScatterStyleAllowed(): boolean;
    set isCustomScatterStyleAllowed(v: boolean);
    /**
     * Gets or sets whether this Scatter series should allow custom style overrides of its individual marker visuals.
    */
    get isCustomScatterMarkerStyleAllowed(): boolean;
    set isCustomScatterMarkerStyleAllowed(v: boolean);
    /**
     * Gets or sets the mode the series will use to find the closest point to the cursor.
    */
    get itemSearchMode(): ScatterItemSearchMode;
    set itemSearchMode(v: ScatterItemSearchMode);
    /**
     * Gets or sets the threshold to use when searching for items using ItemSearchMode.
    */
    get itemSearchThreshold(): number;
    set itemSearchThreshold(v: number);
    findByName(name: string): any;
    protected _styling(container: any, component: any, parent?: any): void;
    private _assigningScatterStyle;
    private _assigningScatterStyle_wrapped;
    /**
     * Event raised when Assigning Category Style
    */
    get assigningScatterStyle(): (s: IgcGeographicProportionalSymbolSeriesComponent, e: IgcAssigningScatterStyleEventArgs) => void;
    set assigningScatterStyle(ev: (s: IgcGeographicProportionalSymbolSeriesComponent, e: IgcAssigningScatterStyleEventArgs) => void);
    private _assigningScatterMarkerStyle;
    private _assigningScatterMarkerStyle_wrapped;
    /**
     * Event raised when Assigning Scatter Marker Style
    */
    get assigningScatterMarkerStyle(): (s: IgcGeographicProportionalSymbolSeriesComponent, e: IgcAssigningScatterMarkerStyleEventArgs) => void;
    set assigningScatterMarkerStyle(ev: (s: IgcGeographicProportionalSymbolSeriesComponent, e: IgcAssigningScatterMarkerStyleEventArgs) => void);
}
