import { IgcGeographicMapSeriesHostComponent } from "./igc-geographic-map-series-host-component";
import { GeographicShapeSeriesBase } from "./GeographicShapeSeriesBase";
import { IgcShapeDataSource } from "igniteui-webcomponents-core";
import { IgcAssigningShapeStyleEventArgs } from "igniteui-webcomponents-charts";
import { IgcAssigningShapeMarkerStyleEventArgs } from "igniteui-webcomponents-charts";
import { ShapeItemSearchMode } from "igniteui-webcomponents-charts";
/**
 * Base class for series which render polygons on a map.
*/
export declare abstract class IgcGeographicShapeSeriesBaseComponent extends IgcGeographicMapSeriesHostComponent {
    /**
                                 * @hidden
                                 */
    get i(): GeographicShapeSeriesBase;
    constructor();
    connectedCallback(): void;
    disconnectedCallback(): void;
    private static _observedAttributesIgcGeographicShapeSeriesBaseComponent;
    static get observedAttributes(): string[];
    private _shapeDataSource;
    /**
     * Gets or sets the string path of the .shp portion of the Shapefile.
    */
    set shapeDataSource(value: string);
    get shapeDataSource(): string;
    private _databaseSource;
    /**
     * Gets or sets the string path of the .dbf portion of the Shapefile.
    */
    set databaseSource(value: string);
    get databaseSource(): string;
    private _currData;
    private _onImportCompleted;
    protected onUpdateDataSource(dataSource: any): any;
    private _cachedShapeDataSource;
    private updateShapeDataSource;
    private onShapeDataSourceImportCompleted;
    /**
     * The name of the property on ItemsSource items which, for each shape, contains a list of points to be converted to a polygon.
     * To be consistent with the Shapefile technical description, it is expected that each list of points is defined as an IEnumerable of IEnumerable of Point, or in other words, a list of lists of points.
    */
    get shapeMemberPath(): string;
    set shapeMemberPath(v: string);
    /**
     * Gets or sets whether this Shape series should allow custom style overrides of its individual visuals.
    */
    get isCustomShapeStyleAllowed(): boolean;
    set isCustomShapeStyleAllowed(v: boolean);
    /**
     * Gets or sets whether this Shape series should allow custom style overrides of its individual marker visuals.
    */
    get isCustomShapeMarkerStyleAllowed(): boolean;
    set isCustomShapeMarkerStyleAllowed(v: boolean);
    /**
     * Gets or sets the mode the series will use to find the closest point to the cursor.
    */
    get itemSearchMode(): ShapeItemSearchMode;
    set itemSearchMode(v: ShapeItemSearchMode);
    /**
     * Gets or sets the threshold to use when searching for items using ItemSearchMode.
    */
    get itemSearchThreshold(): number;
    set itemSearchThreshold(v: number);
    /**
     * Gets or sets the points threshold to use when searching for items using ItemSearchMode.
    */
    get itemSearchPointsThreshold(): number;
    set itemSearchPointsThreshold(v: number);
    /**
     * Set a shapefile datasource to use with the series.
    */
    get shapefileDataSource(): IgcShapeDataSource;
    set shapefileDataSource(v: IgcShapeDataSource);
    /**
     * The resolution at which to filter out shapes in the series.  For example, if the ShapeFilterResolution is set to 3, then elements with a bounding rectangle smaller than 3 X 3 pixels will be filtered out.
     * In the case of GeographicPolylineSeries, the resolution is compared to either dimension, rather than both.  In other words, a polyline will not be filtered if its height or its width exceeds the value of this property.  Whereas with a ShapeSeries, both the height and the width must exceed the value of this property.
    */
    get shapeFilterResolution(): number;
    set shapeFilterResolution(v: number);
    findByName(name: string): any;
    private _assigningShapeStyle;
    private _assigningShapeStyle_wrapped;
    /**
     * Event raised when Assigning Shape Style. Note, if using this event, or highlighting, its best to avoid use of ShapeStyle/StyleShape/ShapeStyleSelector.
    */
    get assigningShapeStyle(): (s: IgcGeographicShapeSeriesBaseComponent, e: IgcAssigningShapeStyleEventArgs) => void;
    set assigningShapeStyle(ev: (s: IgcGeographicShapeSeriesBaseComponent, e: IgcAssigningShapeStyleEventArgs) => void);
    private _assigningShapeMarkerStyle;
    private _assigningShapeMarkerStyle_wrapped;
    /**
     * Event raised when Assigning Shape Marker Style
    */
    get assigningShapeMarkerStyle(): (s: IgcGeographicShapeSeriesBaseComponent, e: IgcAssigningShapeMarkerStyleEventArgs) => void;
    set assigningShapeMarkerStyle(ev: (s: IgcGeographicShapeSeriesBaseComponent, e: IgcAssigningShapeMarkerStyleEventArgs) => void);
}
