import { IgDataTemplate } from "igniteui-webcomponents-core";
import { MarkerType } from "igniteui-webcomponents-charts";
import { MarkerOutlineMode } from "igniteui-webcomponents-charts";
import { MarkerFillMode } from "igniteui-webcomponents-charts";
import { CollisionAvoidanceType } from "igniteui-webcomponents-charts";
import { IgcStyleShapeEventArgs } from "igniteui-webcomponents-charts";
import { IgcGeographicShapeSeriesBaseComponent } from "./igc-geographic-shape-series-base-component";
import { GeographicShapeSeries } from "./GeographicShapeSeries";
/**
 * Series class which renders polygons as Paths, in a geographic context, based on lists of points in the ItemsSource.
*/
export declare class IgcGeographicShapeSeriesComponent extends IgcGeographicShapeSeriesBaseComponent {
    protected createImplementation(): GeographicShapeSeries;
    /**
                                 * @hidden
                                 */
    get i(): GeographicShapeSeries;
    constructor();
    connectedCallback(): void;
    disconnectedCallback(): void;
    private static _observedAttributesIgcGeographicShapeSeriesComponent;
    static get observedAttributes(): string[];
    static htmlTagName: string;
    protected static _isElementRegistered: boolean;
    static register(): void;
    /**
     * Gets whether the current series shows a polygon shape.
    */
    get isPolygon(): boolean;
    /**
     * Gets or sets the fill brush.
    */
    get shapeFill(): string;
    set shapeFill(v: string);
    /**
     * Gets or sets the stroke brush.
    */
    get shapeStroke(): string;
    set shapeStroke(v: string);
    /**
     * Gets or sets the stroke thickness.
    */
    get shapeStrokeThickness(): number;
    set shapeStrokeThickness(v: number);
    /**
     * Gets or sets the opacity.
    */
    get shapeOpacity(): number;
    set shapeOpacity(v: number);
    ensureShapeStyle(): void;
    /**
     * Gets or sets the marker type for the current series object.
     * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
    */
    get markerType(): MarkerType;
    set markerType(v: MarkerType);
    /**
     * Gets or sets whether the marker outline is based on the marker brush of the series rather than the marker outlines collection.
    */
    get markerOutlineMode(): MarkerOutlineMode;
    set markerOutlineMode(v: MarkerOutlineMode);
    /**
     * Gets or sets whether the marker brush is based on the marker outline of the series rather than the marker brushes collection.
    */
    get markerFillMode(): MarkerFillMode;
    set markerFillMode(v: MarkerFillMode);
    /**
     * Gets or sets the MarkerTemplate for the current series object.
    */
    get markerTemplate(): IgDataTemplate;
    set markerTemplate(v: IgDataTemplate);
    /**
     * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
    */
    get markerBrush(): string;
    set markerBrush(v: string);
    /**
     * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
    */
    get markerOutline(): string;
    set markerOutline(v: string);
    /**
     * Gets or sets thickness of the marker outline
    */
    get markerThickness(): number;
    set markerThickness(v: number);
    /**
     * The desired behavior for markers in this series which are placed too close together for the current view, resulting in a collision.
    */
    get markerCollisionAvoidance(): CollisionAvoidanceType;
    set markerCollisionAvoidance(v: CollisionAvoidanceType);
    /**
     * Gets the effective marker template for the current series object.
    */
    get actualMarkerTemplate(): IgDataTemplate;
    set actualMarkerTemplate(v: IgDataTemplate);
    /**
     * Gets the effective marker brush for the current series object.
    */
    get actualMarkerBrush(): string;
    set actualMarkerBrush(v: string);
    /**
     * Gets the effective marker outline for the current series object.
    */
    get actualMarkerOutline(): string;
    set actualMarkerOutline(v: string);
    private _styleShape;
    private _styleShape_wrapped;
    get styleShape(): (s: IgcGeographicShapeSeriesComponent, e: IgcStyleShapeEventArgs) => void;
    set styleShape(ev: (s: IgcGeographicShapeSeriesComponent, e: IgcStyleShapeEventArgs) => void);
}
